pub fn load_defaults() -> Result<LexConfig, ConfigError>Expand description
Convenience helper for callers that only need the defaults.
pub fn load_defaults() -> Result<LexConfig, ConfigError>Convenience helper for callers that only need the defaults.